mibanco_auto_web
mibanco_auto_web es una biblioteca de pruebas funcionales simple que utiliza Python, Selenium y Chrome driver.
Pre-requisitos
Antes de instalar mibanco_auto_web, asegúrate de tener instalado lo siguiente:
- Python 3.12.2
Instalación
Puedes instalar mibanco_auto_web usando pip:
pip install mibanco_auto_web
Si necesitas una versión específica de mibanco_auto_web, puedes especificarla así:
pip install mibanco_auto_web==version
Uso
Una vez instalado, puedes usar mibanco_auto_web con varios argumentos:
| Argumento | Descripción |
|---|---|
| --version | Imprime la versión de mibanco_auto_web. |
| --setup | Copia el directorio de la aplicación e instala las dependencias. |
| --run-tests | Ejecuta las pruebas. |
| --report-html | Genera un informe en html. |
| --report-word | Genera un informe en formato word. |
| --reset | Elimina directorios innecesarios. |
| --open-app | Abre la interfaz de ejecución de pruebas. |
| --open-logs | Abre archivo excel con los logs de ejecución. |
| --modify-data | Abre archivo excel con la data de pruebas. |
| --help -h | Muestra la ayuda y explica cómo usar los argumentos. |
Por ejemplo, para imprimir la versión de mibanco_auto_web, puedes usar:
mibanco_auto_web --version
Para configurar tu aplicación, puedes usar:
mibanco_auto_web --setup
Esto copiará el directorio de la aplicación e instalará las dependencias necesarias.
Para ejecutar las pruebas, debes ubicarte dentro de la carpeta framework_web y ejecutar el siguiente comando:
mibanco_auto_web --run-tests
Para generar un informe en allure html, debes ubicarte dentro de la carpeta framework_web y usar este comando:
mibanco_auto_web --report-html
Para generar un informe en formato word, debes ubicarte dentro de la carpeta framework_web y usar este comando:
mibanco_auto_web --report-word
Para abrir la interfaz de ejecución de pruebas, debes ubicarte dentro de la carpeta framework_web y usar este comando:
mibanco_auto_web --open-app
Para abrir archivo excel con los logs de ejecución, debes ubicarte dentro de la carpeta framework_web y usar este comando:
mibanco_auto_web --open-logs
Para abrir archivo excel con la data de pruebas, debes ubicarte dentro de la carpeta framework_web y usar este comando:
mibanco_auto_web --modify-data
Si desea eliminar carpetas de ejecuciones anteriores, escriba el siguiente comando:
mibanco_auto_web --reset
Para obtener ayuda y saber cómo usar los argumentos, puedes usar:
mibanco_auto_web --help
Metadata
Release files for mibanco-auto-web 1.0.5
For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.
Source distribution (sdist)
| File | Size | Uploaded | Provenance | Actions |
|---|---|---|---|---|
| mibanco_auto_web-1.0.5.tar.gz | 5.4 kB | Without provenance | Details for mibanco_auto_web-1.0.5.tar.gz |
Release files / mibanco_auto_web-1.0.5.tar.gz
| Download URL | mibanco_auto_web-1.0.5.tar.gz |
|---|---|
| Size | 5.4 kB |
| Tags | Source |
|
SHA-256 checksum How to use checksums |
c6e6e492f187530454da521f43f743e3a42c5355145c04961af440cb39504384
|
|
BLAKE2b-256 checksum How to use checksums |
f85dab92e46fd330bf32a3a5ad841c518471aed5f1b03a20f4210c9294d46b33
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.1.1 CPython/3.12.2
|
Security for mibanco-auto-web 1.0.5
Provenance
Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.
No provenance found
None of the files in this release were uploaded with provenance metadata.
A note on package security
PyPI is a repository for distributing packages, not a service for auditing them. While third-party security researchers and our staff do their best to detect and remove malicious packages, PyPI cannot guarantee the quality, security or suitability of any given package.
To learn more about protecting yourself from malicious actors, visit our package security documentation.